about summary refs log tree commit diff stats
path: root/src/ui/window.c
diff options
context:
space:
mode:
authorMichael Vetter <jubalh@iodoru.org>2020-02-21 19:17:12 +0100
committerMichael Vetter <jubalh@iodoru.org>2020-02-21 19:17:12 +0100
commit99dc1c9494f5f84fae4082bac2a0dec5319232ce (patch)
tree8b729ee610ebf69356d8688233588dca9fb3ee85 /src/ui/window.c
parent4b1b035654290dbad24b2e98fe62bea4ebe3aa4d (diff)
downloadprofani-tty-99dc1c9494f5f84fae4082bac2a0dec5319232ce.tar.gz
Rename separator to trackbar
Diffstat (limited to 'src/ui/window.c')
-rw-r--r--src/ui/window.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ui/window.c b/src/ui/window.c
index 9c508e2a..360ed822 100644
--- a/src/ui/window.c
+++ b/src/ui/window.c
@@ -1694,7 +1694,7 @@ _win_print_wrapped(WINDOW *win, const char *const message, size_t indent, int pa
 }
 
 void
-win_print_separator(ProfWin *window)
+win_print_trackbar(ProfWin *window)
 {
     int cols = getmaxx(window->layout->win);
 
@@ -1722,8 +1722,8 @@ win_redraw(ProfWin *window)
         ProfBuffEntry *e = buffer_get_entry(window->layout->buffer, i);
 
         if (e->display_from == NULL && e->message && e->message[0] == '-') {
-            // just an indicator to print the separator not the actual message
-            win_print_separator(window);
+            // just an indicator to print the trackbar/separator not the actual message
+            win_print_trackbar(window);
         } else {
             // regular thing to print
             _win_print_internal(window, e->show_char, e->pad_indent, e->time, e->flags, e->theme_item, e->display_from, e->message, e->receipt);
@@ -1904,7 +1904,7 @@ win_insert_last_read_position_marker(ProfWin *window, char* id)
 
     GDateTime *time = g_date_time_new_now_local();
 
     // the separator will actually be print in win_redraw().
     // this only puts it in the buffer and win_redraw() will interpret it.
     // so that we have the correct length even when resizing.
     buffer_append(window->layout->buffer, " ", 0, time, 0, THEME_TEXT, NULL, "-", NULL, id);
@@ -1904,7 +1904,7 @@ win_insert_last_read_position_marker(ProfWin *window, char* id)
     GDateTime *time = g_date_time_new_now_local();
 
-    // the separator will actually be print in win_redraw().
+    // the trackbar/separator will actually be print in win_redraw().
     // this only puts it in the buffer and win_redraw() will interpret it.
     // so that we have the correct length even when resizing.